# SunTools - Sunrise, sunset, sun altitude and solar flux routines 

A set of routines which calculate the sunrise/set times, converted from Java to Python. Original by Paul Schlyter, written in C.
Miguel Tremblay kindly contributed an updated version, which also can calculate the sun altitude in degrees and maximal solar flux for given day in certain latitude. He also added char-encoding for newer Python versions. Thanks Miguel!
